// Written by Jason Heddings: http://mapit.mozdev.org/
// License: http://creativecommons.org/licenses/by-nc-sa/2.0/

// Here are some links that I'd like to incorporate into the extension...
// http://www.mappoint.com
// http://www.randmcnally.com/rmc/directions/dirGetMapInput.jsp

////////////////////////////////////////////////////////////////////////////////
// Generates a page in a new tab or window

function mapitGeneratePage(url) {
  var settings = new MapItSettings();
  var genPage = window;

  // check where to send the map
  if (settings.target == "tab") {
    getBrowser().selectedTab = getBrowser().addTab(url);
  } else if (settings.target == "blank") {
    genPage = window.open(url);
  } else {
    // the new page is set to the current window
  }

  return genPage;
}

////////////////////////////////////////////////////////////////////////////////
// Creates a form element.

function mapitGenerateInput(page, name, value) {
  var input = page.content.document.createElement("input");
  input.setAttribute("type", "hidden");
  input.setAttribute("name", name);
  input.setAttribute("value", value);
  return input;
}

////////////////////////////////////////////////////////////////////////////////
// Create the MapQuest form.
// http://www.mapquest.com/

function mapitMapQuest(address) {
  // This must be done to make generated content render
  const request = new XMLHttpRequest();
  request.open("GET", window.content.document.URL, true);
  request.send("");

  var page = mapitGeneratePage("about:blank");
  var form = page.content.document.createElement("form")
  form.setAttribute("method", "get");
  form.setAttribute("action", "http://www.mapquest.com/maps/map.adp");

  form.appendChild(mapitGenerateInput(page, "searchtype", "address"));
  form.appendChild(mapitGenerateInput(page, "country", address.country));
  form.appendChild(mapitGenerateInput(page, "address", address.street));
  form.appendChild(mapitGenerateInput(page, "city", address.city));
  form.appendChild(mapitGenerateInput(page, "state", mapitAbbreviateState(address.state)));
  form.appendChild(mapitGenerateInput(page, "zipcode", address.zip));

  page.content.document.body.appendChild(form);
  form.submit();
}

////////////////////////////////////////////////////////////////////////////////
// Create the Maps.com form.
// http://www.maps.com/directions/address/simple_address.html

function mapitMapsDotCom(address) {
  // This must be done to make generated content render
  const request = new XMLHttpRequest();
  request.open("GET", window.content.document.URL, true);
  request.send("");

  var page = mapitGeneratePage("about:blank");
  var form = page.content.document.createElement("form")
  form.setAttribute("method", "post");
  form.setAttribute("action", "http://host.maptuit.com/maps.com/index.cgi");

  form.appendChild(mapitGenerateInput(page, "AddrPickBest", "1"));
  form.appendChild(mapitGenerateInput(page, "Address", address.street));
  form.appendChild(mapitGenerateInput(page, "City", address.city));
  form.appendChild(mapitGenerateInput(page, "Region", mapitAbbreviateState(address.state)));
  form.appendChild(mapitGenerateInput(page, "Postal", address.zip));

  page.content.document.body.appendChild(form);
  form.submit();
}

////////////////////////////////////////////////////////////////////////////////
// Create the GlobeXplorer form.
// http://www.globexplorer.com/

function mapitGlobeXplorer(address) {
  // This must be done to make generated content render
  const request = new XMLHttpRequest();
  request.open("GET", window.content.document.URL, true);
  request.send("");

  var page = mapitGeneratePage("about:blank");
  var form = page.content.document.createElement("form")
  form.setAttribute("method", "post");
  form.setAttribute("action", "http://imageatlas.globexplorer.com/ImageAtlas/view.do?group=ImageAtlas");

  form.appendChild(mapitGenerateInput(page, "address", address.street));
  form.appendChild(mapitGenerateInput(page, "city", address.city));
  form.appendChild(mapitGenerateInput(page, "state", mapitAbbreviateState(address.state)));
  form.appendChild(mapitGenerateInput(page, "zip", address.zip));

  page.content.document.body.appendChild(form);
  form.submit();
}

////////////////////////////////////////////////////////////////////////////////
// Create the TerraServer form.
// http://terraserver.microsoft.com/address.aspx

function mapitTerraServer(address) {
  // This must be done to make generated content render
  const request = new XMLHttpRequest();
  request.open("GET", window.content.document.URL, true);
  request.send("");

  var page = mapitGeneratePage("about:blank");
  var form = page.content.document.createElement("form")
  form.setAttribute("method", "post");
  form.setAttribute("action", "http://terraserver.microsoft.com/address.aspx");

  form.appendChild(mapitGenerateInput(page, "__VIEWSTATE", "dDwxMjYwNjE1NTk0OztsPFNlYXJjaDs+Pg=="));
  form.appendChild(mapitGenerateInput(page, "Street", address.street));
  form.appendChild(mapitGenerateInput(page, "City", address.city));
  form.appendChild(mapitGenerateInput(page, "State", mapitAbbreviateState(address.state)));
  form.appendChild(mapitGenerateInput(page, "ZipCode", address.zip));

  page.content.document.body.appendChild(form);
  form.submit();
}
