// Written by Jason Heddings: http://mapit.mozdev.org/
// License: http://creativecommons.org/licenses/by-nc-sa/2.0/

function MapItSettings() { this._init(); }

////////////////////////////////////////////////////////////////////////////////

MapItSettings.prototype = {

  _init:function() { },

////////////////////////////////////////////////////////////////////////////////
  
  get _prefroot() { return "extensions.mapit.opts."; },

////////////////////////////////////////////////////////////////////////////////
  
  get mapper()    { return this._getPref("gen", "mapper", "mapquest"); },
  set mapper(str) { this._setPref("gen", "mapper", str); },

////////////////////////////////////////////////////////////////////////////////
  
  get target()    { return this._getPref("gen", "target", "top"); },
  set target(str) { this._setPref("gen", "target", str); },

////////////////////////////////////////////////////////////////////////////////

  get verify()    { return this._getPref("gen", "verify", "uncertain"); },
  set verify(str) { this._setPref("gen", "verify", str); },

////////////////////////////////////////////////////////////////////////////////

  get regexps() {
    var regexps = new Array();
    var stored = this._getInt("regexp", "count", 0);

    // these are handy for creating quick regular expressions
    // TODO :jah: should these be available for user prefs?
    var street = "(\\d+\\D*\\s+.*)";
    var city   = "([A-Za-z].*[A-Za-z.])";
    var state  = "([A-Za-z.]*)";
    var zip    = "(\\d{5})";

    if (stored == 0) {
      // set up the default regular expressions...
      regexps.push(street + "[,\\n]\\s*" + city + "[,\\s]+" + state + "\\s+" + zip);

      // these are the original regexp's from the old mapit project
      //regexps.push("^\\D*(\\d+\\D*\\s+.*)\\n*.*\\n(.*)\\,*\\s+(.*)\\s+(\\d{5})");
      //regexps.push("^\\D*(\\d+\\\s+.*)\\n*.*\\n(.*)\\,\\s+(.*)\\s+(\\d{5})");
      //regexps.push("(\\d+\\s+.*)\\s*\\,\\s*(.*)\\s*\\,\\s*(\\w+)\\s+(\\d{5})");

    } else {
      for (var idx = 0; idx < stored; idx++) {
        regexps.push(this._getPref("regexp", "re" + idx, ""));
      }
    }

    return regexps;
  },

  set regexps(regexps) {
    if (regexps && (regexps.length > 0)) {
      this._setInt("regexp", "count", regexps.length);
      for (var idx = 0; idx < regexps.length; idx++) {
        this._setPref("regexp", "re" + idx, regexps[idx]);
      }
    }
  },

////////////////////////////////////////////////////////////////////////////////

  // access the common opts elements
  _setOpts:function(mod, str) { nsPreferences.setUnicharPref(this._prefroot + mod, str); },
  _getOpts:function(mod) { return nsPreferences.copyUnicharPref(this._prefroot + mod, ""); },

////////////////////////////////////////////////////////////////////////////////

  // settings with integer values
  _setInt:function(mod, name, value) { this._setPref(mod, name, value); },
  _getInt:function(mod, name, dfault) { return parseInt(this._getPref(mod, name, dfault)); },

  // settings with boolean values
  _setBool:function(mod, name, value) { this._setInt(mod, name, (value) ? 1 : 0); },
  _getBool:function(mod, name, dfault) { return (this._getInt(mod, name, dfault) == 1) ? true : false; },

////////////////////////////////////////////////////////////////////////////////

  // settings with string values
  _setPref:function(mod, name, value) {
    var newopts = "";

    // remove the name from the current options, if it exists
    var pairs = this._getOpts(mod).split("&");
    for (var idx = 0; idx < pairs.length; idx++) {
      var pair = pairs[idx].split("=");
      if ((pair[0] != name) && (pairs[idx] != "")) {
        newopts += pairs[idx] + "&";
      }
    }

    // add the new string to the options & save the options
    newopts += name + "=" + escape(value);
    this._setOpts(mod, newopts);
  },

////////////////////////////////////////////////////////////////////////////////

  _getPref:function(mod, name, dfault) {
    // scan for the name
    var pairs = this._getOpts(mod).split("&");
    for (var idx = 0; idx < pairs.length; idx++) {
      var pair = pairs[idx].split("=");
      if (pair[0] == name) {
        return unescape(pair[1]);
      }
    }

    // still here?  not found...
    return dfault;
  },

////////////////////////////////////////////////////////////////////////////////
};
